References
==========

.. [bliss_2011] Junttilla, Tommi and Kaski, Petteri. "Conflict Propagation and \
   Component Recursion for Canonical Labeling" 2011 Theory and Practice of \
   Algorithms in (Computer) Systems (TAPAS). Springer, 2011. \
   `(DOI) <https://doi.org/10.1007/978-3-642-19754-3>`__

.. [bliss_2007] Junttilla, Tommi and Kaski, Petteri. Engineering an Efficient \
   Canonical Labeling Tool for Large and Sparse Graphs, 2007 Algorithm \
   Engineering and Experiments (ALENEX). \
   `(DOI) <https://doi.org/10.1137/1.9781611972870>`__
